==> certmanager-model-v1alpha2-6.2.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelector;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorBuilder;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerDNS01ProviderDigitalOceanFluentImpl<A extends ACMEIssuerDNS01ProviderDigitalOceanFluent<A>> extends BaseFluent<A> implements ACMEIssuerDNS01ProviderDigitalOceanFluent<A>{
  public ACMEIssuerDNS01ProviderDigitalOceanFluentImpl() {
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluentImpl(ACMEIssuerDNS01ProviderDigitalOcean instance) {
    this.withTokenSecretRef(instance.getTokenSecretRef()); 
  }
  private SecretKeySelectorBuilder tokenSecretRef;
  
  /**
   * This method has been deprecated, please use method buildTokenSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretKeySelector getTokenSecretRef() {
    return this.tokenSecretRef!=null ?this.tokenSecretRef.build():null;
  }
  public SecretKeySelector buildTokenSecretRef() {
    return this.tokenSecretRef!=null ?this.tokenSecretRef.build():null;
  }
  public A withTokenSecretRef(SecretKeySelector tokenSecretRef) {
    _visitables.get("tokenSecretRef").remove(this.tokenSecretRef);
    if (tokenSecretRef!=null){ this.tokenSecretRef= new SecretKeySelectorBuilder(tokenSecretRef); _visitables.get("tokenSecretRef").add(this.tokenSecretRef);} else { this.tokenSecretRef = null; _visitables.get("tokenSecretRef").remove(this.tokenSecretRef); } return (A) this;
  }
  public Boolean hasTokenSecretRef() {
    return this.tokenSecretRef != null;
  }
  public A withNewTokenSecretRef(String key,String name) {
    return (A)withTokenSecretRef(new SecretKeySelector(key, name));
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluent.TokenSecretRefNested<A> withNewTokenSecretRef() {
    return new ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.TokenSecretRefNestedImpl();
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluent.TokenSecretRefNested<A> withNewTokenSecretRefLike(SecretKeySelector item) {
    return new ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.TokenSecretRefNestedImpl(item);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluent.TokenSecretRefNested<A> editTokenSecretRef() {
    return withNewTokenSecretRefLike(getTokenSecretRef());
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluent.TokenSecretRefNested<A> editOrNewTokenSecretRef() {
    return withNewTokenSecretRefLike(getTokenSecretRef() != null ? getTokenSecretRef(): new SecretKeySelectorBuilder().build());
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluent.TokenSecretRefNested<A> editOrNewTokenSecretRefLike(SecretKeySelector item) {
    return withNewTokenSecretRefLike(getTokenSecretRef() != null ? getTokenSecretRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEIssuerDNS01ProviderDigitalOceanFluentImpl that = (ACMEIssuerDNS01ProviderDigitalOceanFluentImpl) o;
    if (tokenSecretRef != null ? !tokenSecretRef.equals(that.tokenSecretRef) :that.tokenSecretRef != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(tokenSecretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (tokenSecretRef != null) { sb.append("tokenSecretRef:"); sb.append(tokenSecretRef); }
    sb.append("}");
    return sb.toString();
  }
  class TokenSecretRefNestedImpl<N> extends SecretKeySelectorFluentImpl<ACMEIssuerDNS01ProviderDigitalOceanFluent.TokenSecretRefNested<N>> implements ACMEIssuerDNS01ProviderDigitalOceanFluent.TokenSecretRefNested<N>,Nested<N>{
    TokenSecretRefNestedImpl(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    TokenSecretRefNestedImpl() {
      this.builder = new SecretKeySelectorBuilder(this);
    }
    SecretKeySelectorBuilder builder;
    public N and() {
      return (N) ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.this.withTokenSecretRef(builder.build());
    }
    public N endTokenSecretRef() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha2-6.7.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelector;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorBuilder;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerDNS01ProviderDigitalOceanFluentImpl<A extends ACMEIssuerDNS01ProviderDigitalOceanFluent<A>> extends BaseFluent<A> implements ACMEIssuerDNS01ProviderDigitalOceanFluent<A>{
  public ACMEIssuerDNS01ProviderDigitalOceanFluentImpl() {
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluentImpl(ACMEIssuerDNS01ProviderDigitalOcean instance) {
    if (instance != null) {
      this.withTokenSecretRef(instance.getTokenSecretRef());
    }
  }
  private SecretKeySelectorBuilder tokenSecretRef;
  
  /**
   * This method has been deprecated, please use method buildTokenSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretKeySelector getTokenSecretRef() {
    return this.tokenSecretRef!=null ?this.tokenSecretRef.build():null;
  }
  public SecretKeySelector buildTokenSecretRef() {
    return this.tokenSecretRef!=null ?this.tokenSecretRef.build():null;
  }
  public A withTokenSecretRef(SecretKeySelector tokenSecretRef) {
    _visitables.get("tokenSecretRef").remove(this.tokenSecretRef);
    if (tokenSecretRef!=null){ this.tokenSecretRef= new SecretKeySelectorBuilder(tokenSecretRef); _visitables.get("tokenSecretRef").add(this.tokenSecretRef);} else { this.tokenSecretRef = null; _visitables.get("tokenSecretRef").remove(this.tokenSecretRef); } return (A) this;
  }
  public Boolean hasTokenSecretRef() {
    return this.tokenSecretRef != null;
  }
  public A withNewTokenSecretRef(String key,String name) {
    return (A)withTokenSecretRef(new SecretKeySelector(key, name));
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.TokenSecretRefNested<A> withNewTokenSecretRef() {
    return new ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.TokenSecretRefNestedImpl();
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.TokenSecretRefNested<A> withNewTokenSecretRefLike(SecretKeySelector item) {
    return new ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.TokenSecretRefNestedImpl(item);
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.TokenSecretRefNested<A> editTokenSecretRef() {
    return withNewTokenSecretRefLike(getTokenSecretRef());
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.TokenSecretRefNested<A> editOrNewTokenSecretRef() {
    return withNewTokenSecretRefLike(getTokenSecretRef() != null ? getTokenSecretRef(): new SecretKeySelectorBuilder().build());
  }
  public ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.TokenSecretRefNested<A> editOrNewTokenSecretRefLike(SecretKeySelector item) {
    return withNewTokenSecretRefLike(getTokenSecretRef() != null ? getTokenSecretRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerDNS01ProviderDigitalOceanFluentImpl that = (ACMEIssuerDNS01ProviderDigitalOceanFluentImpl) o;
    if (!java.util.Objects.equals(tokenSecretRef, that.tokenSecretRef)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(tokenSecretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (tokenSecretRef != null) { sb.append("tokenSecretRef:"); sb.append(tokenSecretRef); }
    sb.append("}");
    return sb.toString();
  }
  class TokenSecretRefNestedImpl<N> extends SecretKeySelectorFluentImpl<ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.TokenSecretRefNested<N>> implements ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.TokenSecretRefNested<N>,Nested<N>{
    TokenSecretRefNestedImpl(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    TokenSecretRefNestedImpl() {
      this.builder = new SecretKeySelectorBuilder(this);
    }
    SecretKeySelectorBuilder builder;
    public N and() {
      return (N) ACMEIssuerDNS01ProviderDigitalOceanFluentImpl.this.withTokenSecretRef(builder.build());
    }
    public N endTokenSecretRef() {
      return and();
    }
    
  }
  
}
